@@ -4,7 +4,7 @@ import time
 import atexit
 import json
 
-egun_version = "0.0.42 (Tue, 2022-11-29)"
+egun_version = "0.0.44 (Tue, 2022-12-06)"
 
 print(f"Electron source controller: {egun_version}")
 
@@ -903,7 +903,7 @@ class ElectronGunControl:
     def beamOn(self, *ignore, filament_current = None, sync = False):
         if filament_current is not None:
             self.setFilamentOff(sync = sync)
-            self.setFilamentCurrent(filament_current, sync = snyc)
+            self.setFilamentCurrent(filament_current, sync = sync)
         if self.port == False:
             raise ElectronGunNotConnected("Electron gun currently not connected")
         self.port.write(b'$$$beamon\n')
@@ -1110,6 +1110,25 @@ class ElectronGunControl:
             cmd = cmd + b'\n'
             self.port.write(cmd)
 
+    def storeSettings(self):
+        self.port.write(b'$$$storesettings\n');
+
+    def hvpsCalibrateADCPointVolts(self):
+        # This method is used interactively _with unplugged PSU_. The PSU is first set to 0 volts,
+        # then the PSU is given time to converge and then this method is executed
+        # when the displays read 0. Then a voltage is set, the PSU is allowed to
+        # converge and the routine is executed a second time. This will calibrate
+        # the ADC to measure correct voltage.
+        self.port.write(b'$$$calhvpsu\n')
+
+    def hvpsCalibrateADCPointAmps(self):
+        # This method is used interactively _with unplugged PSU_. The PSU is first set to 0 volts,
+        # then the PSU is given time to converge and then this method is executed
+        # when the displays read 0. Then a voltage is set, the PSU is allowed to
+        # converge and the routine is executed a second time. This will calibrate
+        # the ADC to measure correct voltage.
+        self.port.write(b'$$$calhvpsuamp\n')
+
     def jabber(self, *ignore, sync = False):
         if self.port == False:
             raise ElectronGunNotConnected("Electron gun currently not connected")
@@ -1143,14 +1162,14 @@ class ElectronGunControl:
         s += f"\tPyLib version:\t{egun_version}\n"
         s += f"\tController version: {state['id']['version']} (rev. {state['id']['revision']})\n"
         s += f"\tHigh voltage supplies:\n"
-        s += f"\t\tCathode:\t\t{state['hv_voltage'][1]} V, {state['hv_current'][1] / 10.0} uA (mode {state['hv_modes'][1]})\n"
-        s += f"\t\tWhenelt cylinder:\t{state['hv_voltage'][0]} V, {state['hv_current'][0] / 10.0} uA (mode {state['hv_modes'][0]})\n"
-        s += f"\t\tFocus voltage:\t{state['hv_voltage'][2]} V, {state['hv_current'][2] / 10.0} uA (mode {state['hv_modes'][2]})\n"
-        s += f"\t\tAux supply:\t\t{state['hv_voltage'][3]} V, {state['hv_current'][3] / 10.0} uA (mode {state['hv_modes'][3]})\n"
+        s += f"\t\tCathode:\t\t{state['hv_voltage'][1]} V, {state['hv_current'][1]} uA (mode {state['hv_modes'][1]})\n"
+        s += f"\t\tWhenelt cylinder:\t{state['hv_voltage'][0]} V, {state['hv_current'][0]} uA (mode {state['hv_modes'][0]})\n"
+        s += f"\t\tFocus voltage:\t{state['hv_voltage'][2]} V, {state['hv_current'][2]} uA (mode {state['hv_modes'][2]})\n"
+        s += f"\t\tAux supply:\t\t{state['hv_voltage'][3]} V, {state['hv_current'][3]} uA (mode {state['hv_modes'][3]})\n"
         s += f"\tFilament current:\n"
         s += f"\t\tMeasured (high side controller): {state['filament_current']}\n"
 
         return s
 
     def __repr__(self):
-        return "Electron gun controller {egun_version}"
+        return f"Electron gun controller {egun_version}"
